CoTiMAMod1onFullFit_6_cats12: ctmaFit-object with a categorical moderator of the full drift matrix
Description
ctmaFit-object with a categorical moderator of the full drift matrix
Usage
CoTiMAMod1onFullFit_6_cats12
Format
An object of class CoTiMAFit of length 13.