ctmaExtract: ctmaExtract

View source: R/ctmaExtract.R

ctmaExtractR Documentation

ctmaExtract

Description

Extracts objects required for CoTiMA from list of results returned by ctmaGenData to be used afterwards with ctmaPrep

Usage

ctmaExtract(
  activeDirectory = NULL,
  ctmaGenDataList = NULL,
  envir = NULL,
  useRawData = FALSE
)

Arguments

activeDirectory

defines active directory where raw data files are saved. No default.

ctmaGenDataList

list returned by ctmaGenData.

envir

environment where objects should be extracted too. NULL by default. Typically one would use the global environment (envir = globalenv()). Has to be specified if ctmaExtract is set to TRUE.

useRawData

if FALSE (default) empcov objects (empcov1, empcov2, etc.) are created in the global environment. If TRUE, raw data files are created in the activeDirectory and rawData objects (rawData1, rawData2, etc.) are created in the global environment. Note that corresponding empcov or rawData objects are deleted in the global environment if the respective other object is requested.


CoTiMA documentation built on July 20, 2026, 5:08 p.m.

Related to ctmaExtract in CoTiMA...