ctmaOTL: ctmaOTL

View source: R/ctmaOTL.R

ctmaOTLR Documentation

ctmaOTL

Description

Numerically determines the optimal time lag (largest effect magnitude)

Usage

ctmaOTL(
  ctmaFitFit = NULL,
  timeRange = NULL,
  driftMat = NULL,
  undoTimeScaling = NULL,
  digits = 4
)

Arguments

ctmaFitFit

fit object created with ctmaFit

timeRange

time range across which to search for the optimal lag

driftMat

drift matrix. Either a ctmaFit object or a drift matrix has to be supplied

undoTimeScaling

undos time scaling in case the the scaleTime argument was used with ctmaFit

digits

digits used for rounding

Value

A corrected correlation matrix (corEmpcov). Corrections leading to r > 1.0 are set to 1.0.

Examples

## Not run: 
OTL <- ctmaOTL(ctmaFitFit=CoTiMA::CoTiMAFullFit_6_new)
print(OTL)

## End(Not run)


CoTiMA documentation built on July 20, 2026, 5:08 p.m.

Related to ctmaOTL in CoTiMA...