ctmaScaleInits: ctmaScaleInits

View source: R/ctmaScaleInits.R

ctmaScaleInitsR Documentation

ctmaScaleInits

Description

This function re-scales inits for drifts and sets all other inits to 0 (because it is too complicated to re-scale inits for diffusions). It uses the internal transformations of ctStanFit (i.e., tforms) to transform the raw estimates, then re-scale them, and finally use the inverse of tform to supply raw estimates as inits.

Usage

ctmaScaleInits(
  CoTiMAFit = NULL,
  ctsemFit = NULL,
  newTimeScale = NULL,
  autoRefit = FALSE
)

Arguments

CoTiMAFit

Fit object created with ctmaFit

ctsemFit

Fit object created with ctStanFit

newTimeScale

New Time scale

autoRefit

Whether to automatically refit the original model using the new inits


CoTiMA documentation built on July 20, 2026, 5:08 p.m.