| ctmaExtract | R Documentation |
Extracts objects required for CoTiMA from list of results returned by ctmaGenData to be used afterwards with ctmaPrep
ctmaExtract(
activeDirectory = NULL,
ctmaGenDataList = NULL,
envir = NULL,
useRawData = FALSE
)
activeDirectory |
defines active directory where raw data files are saved. No default. |
ctmaGenDataList |
list returned by |
envir |
environment where objects should be extracted too. NULL by default. Typically one would use the global environment (envir = globalenv()). Has to be specified if ctmaExtract is set to TRUE. |
useRawData |
if FALSE (default) empcov objects (empcov1, empcov2, etc.) are created in the global environment. If TRUE, raw data files are created in the activeDirectory and rawData objects (rawData1, rawData2, etc.) are created in the global environment. Note that corresponding empcov or rawData objects are deleted in the global environment if the respective other object is requested. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.