| ctmaMMtoCINT | R Documentation |
Compute covariance of CINT-based random intercepts obtained with a MANIFESTMEANS model specification and vice versa.
ctmaMMtoCINT(
ctmaFitObject = NULL,
undoTimeScaling = FALSE,
digits = 4,
cintCov = NULL,
mmCov = NULL,
drift = NULL
)
ctmaFitObject |
fit object created with ctmaInit or ctmaFit (or with ctStanFit) |
undoTimeScaling |
if FALSE (default), results will correspond to the $randomIntercepts part of the summary of the equivalent model with indVarying="CINT" |
digits |
digits used for rounding |
cintCov |
Covariance matrix of continuous time intercepts and T0MEANS (default NULL). Requires drift matrix of same dimensions to be supplied, too. |
mmCov |
Covariance matrix of manifest means and T0MEANS (default NULL). Requires drift matrix of same dimensions to be supplied, too. |
drift |
matrix of drift parameters (default NULL). When drift together with cintCov or mmCov is supplied, any ctmaFitObject supplied is ignored. |
returns covariance of CINT-based random intercepts.
## Not run:
RI_cov <- ctmaMMtoCINT(ctmaFitObject=CoTiMAFullFit_3)
print(RI_cov)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.