| ctmaOTL | R Documentation |
Numerically determines the optimal time lag (largest effect magnitude)
ctmaOTL(
ctmaFitFit = NULL,
timeRange = NULL,
driftMat = NULL,
undoTimeScaling = NULL,
digits = 4
)
ctmaFitFit |
fit object created with ctmaFit |
timeRange |
time range across which to search for the optimal lag |
driftMat |
drift matrix. Either a ctmaFit object or a drift matrix has to be supplied |
undoTimeScaling |
undos time scaling in case the the scaleTime argument was used with ctmaFit |
digits |
digits used for rounding |
A corrected correlation matrix (corEmpcov). Corrections leading to r > 1.0 are set to 1.0.
## Not run:
OTL <- ctmaOTL(ctmaFitFit=CoTiMA::CoTiMAFullFit_6_new)
print(OTL)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.